"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_router_dom_1 = require("react-router-dom");
const documenter_ui_section_1 = require("@teambit/documenter.ui.section");
const documenter_theme_theme_compositions_1 = require("@teambit/documenter.theme.theme-compositions");
const documenter_ui_separator_1 = require("@teambit/documenter.ui.separator");
const version_dropdown_1 = require("./version-dropdown");
function Overview() {
    return (react_1.default.createElement(documenter_theme_theme_compositions_1.ThemeCompositions, null,
        react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(documenter_ui_section_1.Section, null,
                "The version-dropdown displays the latest version of the viewed component. ",
                react_1.default.createElement("br", null),
                "If previous versions are available, the component will display a list of them, when clicked. ",
                react_1.default.createElement("br", null),
                "This allows the user to navigate to previous versions, and explore them."),
            react_1.default.createElement(documenter_ui_separator_1.Separator, null))));
}
exports.default = Overview;
Overview.abstract = 'The version-dropdown lists the latest and previous versions of the viewed component.';
Overview.labels = ['react', 'typescript', 'version', 'dropdown'];
const style = { display: 'flex', justifyContent: 'center', alignContent: 'center' };
Overview.examples = [
    {
        scope: {
            VersionDropdown: version_dropdown_1.VersionDropdown,
            style,
        },
        title: 'Version Dropdown',
        description: 'Using the Version Dropdown component with one verion',
        code: `
    () => {
      return (
        <div style={{...style, minHeight: 150 }}>
          <VersionDropdown versions={['0.1']} currentVersion="0.1" />
        </div>
      );
    }
      `,
    },
    {
        scope: {
            VersionDropdown: version_dropdown_1.VersionDropdown,
            style,
            MemoryRouter: react_router_dom_1.MemoryRouter,
        },
        title: 'Version Dropdown with multiple versions',
        description: 'Using the Version Dropdown component with more than one version',
        code: `
    () => {
      const versions = ['0.3', '0.2', '0.1'];
      return (
        <div style={{...style, minHeight: 400, alignItems: 'end', justifyContent: 'flex-end', margin: 10 }}>
          <MemoryRouter>
            <VersionDropdown versions={versions} currentVersion={versions[0]} />
          </MemoryRouter>
        </div>
      );
    }
      `,
    },
];
//# sourceMappingURL=version-dropdown.docs.js.map